==> alexaplusunity-0.0.7.tgz: package/index.js <==
/*global alert, globalNS*/
/*eslint no-unused-vars: "off"*/
/**
 * Alexa Gaming (via PubNub and AWS)
 * 
 * Created by Austin Wilson
 * 
 * Built to help bring Alexa into games
 * 
 * Notes:
 * For sessionAttributes, use handlerInput.attributesManager.getPersistentAttributes()
 * and handlerInput.attributesManager.setPersistentAttributes(attributes)
 * 
 * Add attribute manager to simplify communication between alexa and game
 * 
 * @class AlexaPlusUnity 
 * @classdesc Built to help bring Alexa into Unity3d projects.
 */

class AlexaPlusUnity {

    /**
     * Create new AlexaPlusUnity Instance.
     * @constructor
     * @param {string} publishKey - Your PubNub publish key.
     * @param {string} subscribeKey - Your PubNub subscribe key.
     * @param {bool} [debug=false] - True to enable detailed logs.
     */
    constructor(publishKey, subscribeKey, debug) {
        var ref = this;
        ref.PubNub = require('pubnub');
        ref.pubnub = null;
        ref.debug = false;
        ref.setDebug(debug);
        ref.setPubNub(publishKey, subscribeKey);
    }

    /**
     * Enable/Disable detailed logs.
     * @param {bool} debug - True to enable detailed logs.
     */
    setDebug(debug) {
        var ref = this;
        ref.debug = debug;
    }

    /**
     * Update PubNub instance.
     * @param {string} publishKey - Your PubNub publish key.
     * @param {string} subscribeKey - Your PubNub subscribe key.
     */
    setPubNub(publishKey, subscribeKey) {
        var ref = this;
        ref.pubnub = new ref.PubNub({
            publishKey : publishKey,
            subscribeKey : subscribeKey
        })
    }

    /**
     * Add channel to channel group.
     * @param {string} channel - Channel to add.
     * @param {string} channelGroup - Group to add channel to.
     * 
     * @returns {Promise}
     */
    addChannelToGroup(channel, channelGroup) {
        var ref = this;
        return new Promise((resolve, reject) =>  {
            if(ref.pubnub == null) {
                if(ref.debug) console.log("Error", "You must call setPubNub()!");
                reject({
                    message: "You must call setPubNub()!"
                });
            }
            ref.channelGroup = channelGroup;
            ref.pubnub.channelGroups.addChannels(
                {
                    channels: [
                        channel + "A",
                        channel + "B"
                    ],
                    channelGroup: channelGroup
                }, 
                function(status) {
                    if (status.error) {
                        if(ref.debug) console.log("Error", status);
                        reject(status);
                    } else {
                        if(ref.debug) console.log("Add Channels Success", status);
                        resolve(status);
                    }
                }
            );
        });
    }

    /**
     * Publish message to Unity.
     * @param {string} message - Message to send.
     * @param {string} channel - Channel to send message over.
     * 
     * @returns {Promise}
     */
    publishMessage(message, channel) {
        var ref = this;
        return new Promise((resolve, reject) =>  {
            var ref = this;
            if(ref.pubnub == null) {
                if(ref.debug) console.log("Error", "You must call setPubNub()!");
                reject({
                    message: "You must call setPubNub()!"
                });
            }
            // Create publish parameters
            // Format: {type: <VALUE>, message: <VALUE>}
            var params = {
                message: message,
                channel: channel + "A"
            };
            ref.pubnub.publish(params, function(status, response) {
                if (status.error) {
                    if(ref.debug) console.log("Error", status);
                    reject(status);
                } else {
                    if(ref.debug) console.log("Publish Success", response);
                    resolve(response);
                }
            });
        });
    }

    /**
     * Publish message to Unity and listen for response.
     * @param {string} message - Message to send.
     * @param {string} channel - Channel to send message over.
     * @param {number} [timeout=1000] - Listener timeout in milliseconds.
     * 
     * @returns {Promise}
     */
    publishMessageAndListenToResponse(message, channel, timeout = 1000) {
        var ref = this;
        return new Promise((resolve, reject) => {
            if(ref.pubnub == null) {
                if(ref.debug) console.log("Error", "You must call setPubNub()!");
                reject({
                    message: "You must call setPubNub()!"
                });
            }

            ref.publishMessage(message, channel).then((data) => {
                var pubnubSub = ref.pubnub;

                let timer = setTimeout(() => {
                    ref.pubnub.removeListener(listener);
                    ref.pubnub.stop();
                    clearTimeout(timer);
                    reject({
                        message: "Game did not respond in time!"
                    });
                }, timeout);

                var listener = {
                    status: function(statusEvent) {
                        if (statusEvent.category === "PNConnectedCategory") {
                            
                        }
                    },
                    message: function(msg) {
                        ref.pubnub.removeListener(listener);
                        ref.pubnub.stop();
                        clearTimeout(timer);
                        if(ref.debug) console.log("Subscribe Success", msg);
                        resolve(msg);
                    }
                };

                ref.pubnub.addListener(listener);
                
                ref.pubnub.subscribe({
                    channels: [channel + "B"] 
                });
            }).catch((err) => {
                if(ref.debug) console.log("Error", err);
                reject(err);
            });
        });
    }

    /**
     * List channels in channel group.
     * @param {string} channelGroup - Channel group to find channels in.
     * 
     * @returns {Promise}
     */
    listChannels(channelGroup) {
        var ref = this;
        return new Promise((resolve, reject) =>  {
            if(ref.pubnub == null) {
                if(ref.debug) console.log("Error", "You must call setPubNub()!");
                reject({
                    message: "You must call setPubNub()!"
                });
            }
            ref.pubnub.channelGroups.listChannels(
                {
                    channelGroup: channelGroup
                }, 
                function (status, response) {
                    if (status.error) {
                        if(ref.debug) console.log("Error", status);
                        reject(status);
                    } else {
                        if(ref.debug) console.log("List Channels Success", response);
                        resolve(response);
                    }
                }
            );
        });
    }

    /**
     * Create and add new unique channel to channel group.
     * @param {string} channelGroup - Channel group create new, unique channel in.
     * 
     * @returns {string}
     */
    uniqueQueueGenerator(channelGroup) {
        var ref = this;
        var channel = ref.listChannels(channelGroup).then((data) => {
            var channels = data.channels;
            var newChannel = ref.makeId();
            if(channels) {
                while(channels.includes(newChannel + "A")) {
                    newChannel = ref.makeId();
                }
            }
            if(ref.debug) console.log("New Channel Created: " + newChannel);
            return newChannel;
        }).catch((err) => {
            if(ref.debug) console.log("Error", err);
        });
        return channel;
    }

    /**
     * Make new 5 charecter ID.
     * @returns {string}
     */
    makeId() {
        var text = "";
        var possible = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
        
        for (var i = 0; i < 5; i++) {
            text += possible.charAt(Math.floor(Math.random() * possible.length));
        }
        return text;
    }
}

module.exports = AlexaPlusUnity;

==> alexaplusunity-0.0.9.tgz: package/index.js <==
/*global alert, globalNS*/
/*eslint no-unused-vars: "off"*/
/**
 * Alexa Gaming (via PubNub and AWS)
 * 
 * Created by Austin Wilson
 * 
 * Built to help bring Alexa into games
 * 
 * Notes:
 * For sessionAttributes, use handlerInput.attributesManager.getPersistentAttributes()
 * and handlerInput.attributesManager.setPersistentAttributes(attributes)
 * 
 * Add attribute manager to simplify communication between alexa and game
 * 
 * @class AlexaPlusUnity 
 * @classdesc Built to help bring Alexa into Unity3d projects.
 */

class AlexaPlusUnity {

    /**
     * Create new AlexaPlusUnity Instance.
     * @constructor
     * @param {string} publishKey - Your PubNub publish key.
     * @param {string} subscribeKey - Your PubNub subscribe key.
     * @param {bool} [debug=false] - True to enable detailed logs.
     */
    constructor(publishKey, subscribeKey, debug) {
        var ref = this;
        ref.PubNub = require('pubnub');
        ref.pubnub = null;
        ref.debug = false;
        ref.setDebug(debug);
        ref.updatePubNub(publishKey, subscribeKey);
    }

    /**
     * Enable/Disable detailed logs.
     * @param {bool} debug - True to enable detailed logs.
     */
    setDebug(debug) {
        var ref = this;
        ref.debug = debug;
    }

    /**
     * Update PubNub instance.
     * @param {string} publishKey - Your PubNub publish key.
     * @param {string} subscribeKey - Your PubNub subscribe key.
     */
    updatePubNub(publishKey, subscribeKey) {
        var ref = this;
        ref.pubnub = new ref.PubNub({
            publishKey : publishKey,
            subscribeKey : subscribeKey
        })
    }

    /**
     * Add channel to channel group.
     * @param {string} channel - Channel to add.
     * @param {string} channelGroup - Group to add channel to.
     * 
     * @returns {Promise}
     */
    addChannelToGroup(channel, channelGroup) {
        var ref = this;
        return new Promise((resolve, reject) =>  {
            if(ref.pubnub == null) {
                if(ref.debug) console.log("Error", "You must call setPubNub()!");
                reject({
                    message: "You must call setPubNub()!"
                });
            }
            ref.channelGroup = channelGroup;
            ref.pubnub.channelGroups.addChannels(
                {
                    channels: [
                        channel + "A",
                        channel + "B"
                    ],
                    channelGroup: channelGroup
                }, 
                function(status) {
                    if (status.error) {
                        if(ref.debug) console.log("Error", status);
                        reject(status);
                    } else {
                        if(ref.debug) console.log("Add Channels Success", status);
                        resolve(status);
                    }
                }
            );
        });
    }

    /**
     * Publish message to Unity.
     * @param {string} message - Message to send.
     * @param {string} channel - Channel to send message over.
     * 
     * @returns {Promise}
     */
    publishMessage(message, channel) {
        var ref = this;
        return new Promise((resolve, reject) =>  {
            var ref = this;
            if(ref.pubnub == null) {
                if(ref.debug) console.log("Error", "You must call setPubNub()!");
                reject({
                    message: "You must call setPubNub()!"
                });
            }
            // Create publish parameters
            // Format: {type: <VALUE>, message: <VALUE>}
            var params = {
                message: message,
                channel: channel + "A"
            };
            ref.pubnub.publish(params, function(status, response) {
                if (status.error) {
                    if(ref.debug) console.log("Error", status);
                    reject(status);
                } else {
                    if(ref.debug) console.log("Publish Success", response);
                    resolve(response);
                }
            });
        });
    }

    /**
     * Publish message to Unity and listen for response.
     * @param {string} message - Message to send.
     * @param {string} channel - Channel to send message over.
     * @param {number} [timeout=1000] - Listener timeout in milliseconds.
     * 
     * @returns {Promise}
     */
    publishMessageAndListenToResponse(message, channel, timeout = 1000) {
        var ref = this;
        return new Promise((resolve, reject) => {
            if(ref.pubnub == null) {
                if(ref.debug) console.log("Error", "You must call setPubNub()!");
                reject({
                    message: "You must call setPubNub()!"
                });
            }

            ref.publishMessage(message, channel).then((data) => {
                var pubnubSub = ref.pubnub;

                let timer = setTimeout(() => {
                    ref.pubnub.removeListener(listener);
                    ref.pubnub.stop();
                    clearTimeout(timer);
                    reject({
                        message: "Game did not respond in time!"
                    });
                }, timeout);

                var listener = {
                    status: function(statusEvent) {
                        if (statusEvent.category === "PNConnectedCategory") {
                            
                        }
                    },
                    message: function(msg) {
                        ref.pubnub.removeListener(listener);
                        ref.pubnub.stop();
                        clearTimeout(timer);
                        if(ref.debug) console.log("Subscribe Success", msg);
                        resolve(msg);
                    }
                };

                ref.pubnub.addListener(listener);
                
                ref.pubnub.subscribe({
                    channels: [channel + "B"] 
                });
            }).catch((err) => {
                if(ref.debug) console.log("Error", err);
                reject(err);
            });
        });
    }

    /**
     * List channels in channel group.
     * @param {string} channelGroup - Channel group to find channels in.
     * 
     * @returns {Promise}
     */
    listChannels(channelGroup) {
        var ref = this;
        return new Promise((resolve, reject) =>  {
            if(ref.pubnub == null) {
                if(ref.debug) console.log("Error", "You must call setPubNub()!");
                reject({
                    message: "You must call setPubNub()!"
                });
            }
            ref.pubnub.channelGroups.listChannels(
                {
                    channelGroup: channelGroup
                }, 
                function (status, response) {
                    if (status.error) {
                        if(ref.debug) console.log("Error", status);
                        reject(status);
                    } else {
                        if(ref.debug) console.log("List Channels Success", response);
                        resolve(response);
                    }
                }
            );
        });
    }

    /**
     * Create and add new unique channel to channel group.
     * @param {string} channelGroup - Channel group create new, unique channel in.
     * 
     * @returns {string}
     */
    uniqueQueueGenerator(channelGroup) {
        var ref = this;
        var channel = ref.listChannels(channelGroup).then((data) => {
            var channels = data.channels;
            var newChannel = ref.makeId();
            if(channels) {
                while(channels.includes(newChannel + "A")) {
                    newChannel = ref.makeId();
                }
            }
            if(ref.debug) console.log("New Channel Created: " + newChannel);
            return newChannel;
        }).catch((err) => {
            if(ref.debug) console.log("Error", err);
        });
        return channel;
    }

    /**
     * Make new 5 charecter ID.
     * @returns {string}
     */
    makeId() {
        var text = "";
        var possible = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
        
        for (var i = 0; i < 5; i++) {
            text += possible.charAt(Math.floor(Math.random() * possible.length));
        }
        return text;
    }
}

module.exports = AlexaPlusUnity;
